from fastapi import FastAPI, HTTPException
from typing import Optional
from pydantic import BaseModel, HttpUrl
import asyncio
from .analyzer import SEOAnalyzer
from .crawler import WebsiteCrawler
from .cli import is_full_website

app = FastAPI(
    title="SEO Analyzer API",
    description="API for analyzing SEO metrics of web pages and crawling websites",
    version="1.0.0"
)

class AnalyzeRequest(BaseModel):
    url: HttpUrl
    max_pages: Optional[int] = 100
    delay: Optional[float] = 1.0

@app.post("/analyze/page")
async def analyze_page(request: AnalyzeRequest):
    """Analyze SEO metrics for a single page"""
    try:
        analyzer = SEOAnalyzer()
        results = analyzer.analyze_page(str(request.url))
        return results
    except Exception as e:
        raise HTTPException(status_code=500, detail=str(e))

@app.post("/analyze/website")
async def analyze_website(request: AnalyzeRequest):
    """Crawl and analyze an entire website"""
    try:
        if not is_full_website(str(request.url)):
            raise HTTPException(
                status_code=400,
                detail="Provided URL is not a website homepage. Please provide a root domain URL."
            )

        crawler = WebsiteCrawler(
            str(request.url),
            max_pages=request.max_pages,
            delay=request.delay
        )
        results = await crawler.crawl()
        return results
    except Exception as e:
        raise HTTPException(status_code=500, detail=str(e))